@@ -1,5 +1,4 @@
 import copy
-import inspect
 import json
 import os
 from os.path import join, splitext, expanduser
@@ -40,6 +39,8 @@ class DataProxy(object):
         All methods (of this object or in subclasses) must take care to
         initialize new attributes via ``self._set(name='value')``, or they'll
         run into recursion errors!
+
+    .. versionadded:: 1.0
     """
     # Attributes which get proxied through to inner merged-dict config obj.
     _proxies = tuple("""
@@ -79,6 +80,8 @@ class DataProxy(object):
             Optional tuple describing the path of keys leading to this
             DataProxy's location inside the ``root`` structure. Required if
             ``root`` was given (and vice versa.)
+
+        .. versionadded:: 1.0
         """
         obj = cls()
         obj._set(_config=data)
@@ -109,7 +112,7 @@ class DataProxy(object):
     def __setattr__(self, key, value):
         # Turn attribute-sets into config updates anytime we don't have a real
         # attribute with the given name/key.
-        has_real_attr = key in (x[0] for x in inspect.getmembers(self))
+        has_real_attr = key in dir(self)
         if not has_real_attr:
             # Make sure to trigger our own __setitem__ instead of going direct
             # to our internal dict/cache
@@ -372,8 +375,8 @@ class Config(DataProxy):
     part of its execution `.Context`.
 
     Any modifications made directly to the `.Config` itself after this point
-    end up stored in their own (topmost) config level, making it easy to debug
-    final values.
+    end up stored in their own (topmost) config level, making it easier to
+    debug final values.
 
     Finally, any *deletions* made to the `.Config` (e.g. applications of
     dict-style mutators like ``pop``, ``clear`` etc) are also tracked in their
@@ -407,6 +410,8 @@ class Config(DataProxy):
       default.
 
       Defaults to ``None``, meaning to use the value of ``prefix``.
+
+    .. versionadded:: 1.0
     """
     prefix = 'invoke'
     file_prefix = None
@@ -423,6 +428,8 @@ class Config(DataProxy):
         Subclasses may choose to override this method, calling
         ``Config.global_defaults`` and applying `.merge_dicts` to the result,
         to add to or modify these values.
+
+        .. versionadded:: 1.0
         """
         # On Windows, which won't have /bin/bash, check for a set COMSPEC env
         # var (https://en.wikipedia.org/wiki/COMSPEC) or fallback to an
@@ -649,6 +656,8 @@ class Config(DataProxy):
             ``True``.
 
         :returns: ``None``.
+
+        .. versionadded:: 1.0
         """
         self._set(_defaults=data)
         if merge:
@@ -665,6 +674,8 @@ class Config(DataProxy):
             ``True``.
 
         :returns: ``None``.
+
+        .. versionadded:: 1.0
         """
         self._set(_overrides=data)
         if merge:
@@ -682,6 +693,8 @@ class Config(DataProxy):
             ``True``.
 
         :returns: ``None``.
+
+        .. versionadded:: 1.0
         """
         self._load_file(prefix='system', merge=merge)
 
@@ -697,6 +710,8 @@ class Config(DataProxy):
             ``True``.
 
         :returns: ``None``.
+
+        .. versionadded:: 1.0
         """
         self._load_file(prefix='user', merge=merge)
 
@@ -717,12 +732,16 @@ class Config(DataProxy):
             ``True``.
 
         :returns: ``None``.
+
+        .. versionadded:: 1.0
         """
         self._load_file(prefix='project', merge=merge)
 
     def set_runtime_path(self, path):
         """
         Set the runtime config file path.
+
+        .. versionadded:: 1.0
         """
         # Path to the user-specified runtime config file.
         self._set(_runtime_path=path)
@@ -745,6 +764,8 @@ class Config(DataProxy):
             ``True``.
 
         :returns: ``None``.
+
+        .. versionadded:: 1.0
         """
         self._load_file(prefix='runtime', absolute=True, merge=merge)
 
@@ -761,6 +782,8 @@ class Config(DataProxy):
 
         See :ref:`env-vars` for details on this design decision and other info
         re: how environment variables are scanned and loaded.
+
+        .. versionadded:: 1.0
         """
         # Force merge of existing data to ensure we have an up to date picture
         debug("Running pre-merge for shell env loading...")
@@ -778,6 +801,8 @@ class Config(DataProxy):
         `.load_collection` is intended for use by the core task execution
         machinery, which is responsible for obtaining collection-driven data.
         See :ref:`collection-configuration` for details.
+
+        .. versionadded:: 1.0
         """
         debug("Loading collection configuration")
         self._set(_collection=data)
@@ -789,6 +814,8 @@ class Config(DataProxy):
         Set the directory path where a project-level config file may be found.
 
         Does not do any file loading on its own; for that, see `load_project`.
+
+        .. versionadded:: 1.0
         """
         # 'Prefix' to match the other sets of attrs
         project_prefix = None
@@ -846,9 +873,9 @@ class Config(DataProxy):
                         type_, filepath, self._file_suffixes))
                 # Store data, the path it was found at, and fact that it was
                 # found
-                setattr(self, data, loader(filepath))
-                setattr(self, path, filepath)
-                setattr(self, found, True)
+                self._set(data, loader(filepath))
+                self._set(path, filepath)
+                self._set(found, True)
                 break
             # Typically means 'no such file', so just note & skip past.
             except IOError as e:
@@ -860,7 +887,7 @@ class Config(DataProxy):
                     raise
         # Still None -> no suffixed paths were found, record this fact
         if getattr(self, path) is None:
-            setattr(self, found, False)
+            self._set(found, False)
         # Merge loaded data in if any was found
         elif merge:
             self.merge()
@@ -884,26 +911,14 @@ class Config(DataProxy):
             data[key] = value
         return data
 
-    @property
-    def paths(self):
-        """
-        An iterable of all successfully loaded config file paths.
-
-        No specific order.
-        """
-        paths = []
-        for prefix in "system user project runtime".split():
-            value = getattr(self, "_{}_path".format(prefix))
-            if value is not None:
-                paths.append(value)
-        return paths
-
     def merge(self):
         """
         Merge all config sources, in order.
+
+        .. versionadded:: 1.0
         """
         debug("Merging config sources in order onto new empty _config...")
-        self._config = {}
+        self._set(_config={})
         debug("Defaults: {!r}".format(self._defaults))
         merge_dicts(self._config, self._defaults)
         debug("Collection-driven: {!r}".format(self._collection))
@@ -975,6 +990,8 @@ class Config(DataProxy):
         :raises:
             ``TypeError``, if ``into`` is given a value and that value is not a
             `.Config` subclass.
+
+        .. versionadded:: 1.0
         """
         # Sanity check for 'into'
         if into is not None and not issubclass(into, self.__class__):
@@ -1021,7 +1038,7 @@ class Config(DataProxy):
             # NOTE: presumably someone could really screw up and change these
             # values' types, but at that point it's on them...
             if not isinstance(my_data, dict):
-                setattr(new, name, copy.copy(my_data))
+                new._set(name, copy.copy(my_data))
             # Dict data gets merged (which also involves a copy.copy
             # eventually)
             else:
@@ -1146,6 +1163,8 @@ def merge_dicts(base, updates):
     :returns:
         The value of ``base``, which is mostly useful for wrapper functions
         like `copy_dict`.
+
+    .. versionadded:: 1.0
     """
     # TODO: for chrissakes just make it return instead of mutating?
     for key, value in updates.items():
@@ -1196,6 +1215,8 @@ def copy_dict(source):
 
     Uses `merge_dicts` under the hood, with an empty ``base`` dict; see its
     documentation for details on behavior.
+
+    .. versionadded:: 1.0
     """
     return merge_dicts({}, source)
 
@@ -1203,6 +1224,8 @@ def copy_dict(source):
 def excise(dict_, keypath):
     """
     Remove key pointed at by ``keypath`` from nested dict ``dict_``, if exists.
+
+    .. versionadded:: 1.0
     """
     data = dict_
     keypath = list(keypath)
@@ -1220,6 +1243,8 @@ def excise(dict_, keypath):
 def obliterate(base, deletions):
     """
     Remove all (nested) keys mentioned in ``deletions``, from ``base``.
+
+    .. versionadded:: 1.0
     """
     for key, value in six.iteritems(deletions):
         if isinstance(value, dict):
